@@ -7,7 +7,7 @@
 #'returns an RGB array.
 #'@param preview Default `FALSE`. If `TRUE`, it will display the image in addition
 #'to returning it.
-#'@param title_text Default `NULL`. Text. Adds a title to the image, using magick::image_annotate.
+#'@param title_text Default `NULL`. Text. Adds a title to the image, using `magick::image_annotate()`.
 #'@param title_offset Default `c(15,15)`. Distance from the top-left (default, `gravity` direction in
 #'image_annotate) corner to offset the title.
 #'@param title_size Default `30`. Font size in pixels.
@@ -17,40 +17,42 @@
 #'@param title_style Default `normal`. Font style (e.g. `italic`).
 #'@param title_bar_color Default `NULL`. If a color, this will create a colored bar under the title.
 #'@param title_bar_alpha Default `0.5`. Transparency of the title bar.
-#'@param title_bar_width Default `NULL`, automatic. Width of the title bar in pixels.
+#'@param title_bar_width Default `NULL`, automaticly calculated from the size of the text and
+#'the number of line breaks. Width of the title bar in pixels.
 #'@param title_position Default `northwest`. Position of the title.
 #'@return 3-layer RGB array of the processed image.
 #'@import grDevices
 #'@export
 #'@examples
-#'#if(interactive()){
+#'if(rayimage:::run_documentation()){
 #'#Plot the dragon
-#'\donttest{
 #'add_title(dragon, preview = TRUE, title_text = "Dragon", title_size=20)
 #'}
+#'if(rayimage:::run_documentation()){
 #'#That's hard to see--let's add a title bar:
-#'\donttest{
 #'add_title(dragon, preview = TRUE, title_text = "Dragon", title_size=20,
 #'          title_bar_color="white")
 #'}
-#'
+#'if(rayimage:::run_documentation()){
 #'#Change the width of the bar:
-#'\donttest{
 #'add_title(dragon, preview = TRUE, title_text = "Dragon", title_size=20,
 #'          title_bar_color="white", title_offset = c(12,12))
 #'}
+#'if(rayimage:::run_documentation()){
+#'#The width of the bar will also automatically adjust for newlines:
+#'add_title(dragon, preview = TRUE, title_text = "Dragon\n(Blue)", title_size=20,
+#'          title_bar_color="white", title_offset = c(12,12))
+#'}
+#'if(rayimage:::run_documentation()){
 #'#Change the color and title color:
-#'\donttest{
 #'add_title(dragon, preview = TRUE, title_text = "Dragon", title_size=20,
 #'          title_bar_color="red", title_color = "white", title_offset = c(12,12))
 #'}
-#'
+#'if(rayimage:::run_documentation()){
 #'#Change the transparency:
-#'\donttest{
 #'add_title(dragon, preview = TRUE, title_text = "Dragon", title_size=20, title_bar_alpha = 0.8,
 #'          title_bar_color="red", title_color = "white", title_offset = c(12,12))
 #'}
-#'#end}
 add_title = function(image,
                      title_text = "", title_offset = c(15,15),
                      title_color = "black", title_size = 30,
@@ -87,11 +89,17 @@ add_title = function(image,
   if(!("magick" %in% rownames(utils::installed.packages()))) {
     stop("`magick` package required for adding title")
   }
+
   if(!is.null(title_bar_color)) {
     title_bar_color = col2rgb(title_bar_color)/255
     title_bar = array(0,c(dimensions[1],dimensions[2],4))
     if(is.null(title_bar_width)) {
-      title_bar_width = 2 * title_offset[2] + title_size
+      #Detect newlines and adjust title bar width
+      char_vector = unlist(strsplit(title_text,""))
+      newline_indices = which(char_vector == "\n")
+      newline_indices = newline_indices[newline_indices != length(char_vector)]
+      newlines = length(newline_indices)
+      title_bar_width = 2 * title_offset[2] + title_size * (1 + newlines)
     }
     if(title_bar_width > dimensions[1]) {
       message(paste0(c("Input title_bar_width (", title_bar_width,
@@ -118,16 +126,16 @@ add_title = function(image,
     }
     title_bar_temp = paste0(tempfile(),".png")
     png::writePNG(title_bar,title_bar_temp)
-    magick::image_read(temp) %>%
+    magick::image_read(temp) |>
       magick::image_composite(magick::image_read(title_bar_temp),
-      ) %>%
+      ) |>
       magick::image_write(path = temp, format = "png")
   }
-  magick::image_read(temp) %>%
+  magick::image_read(temp) |>
     magick::image_annotate(title_text,
                            location = paste0("+", title_offset[1],"+",title_offset[2]),
                            size = title_size, color = title_color, style = title_style,
-                           font = title_font, gravity = title_position) %>%
+                           font = title_font, gravity = title_position) |>
     magick::image_write(path = temp, format = "png")
   temp = png::readPNG(temp)
   if(length(dim(temp)) == 3 && dim(temp)[3] == 2) {
