@@ -9,6 +9,7 @@
 #'@param asp Default `1`. Aspect ratio of the pixels in the plot. For example, an aspect ratio of `4/3` will
 #'slightly widen the image.
 #'@param new_page  Default `TRUE`. Whether to call `grid::grid.newpage()` before plotting the image.
+#'@param return_grob Default `FALSE`. Whether to return the grob object.
 #'@param ... Additional arguments to pass to the `raster::plotRGB` function that displays the map.
 #'@export
 #'@examples
@@ -17,7 +18,7 @@
 #'plot_image(dragon)
 #'#end}
 plot_image = function(input, rotate=0, keep_user_par = FALSE,
-                      asp = 1, new_page = TRUE, ...) {
+                      asp = 1, new_page = TRUE, return_grob = FALSE, ...) {
   imagetype = get_file_type(input)
   if(imagetype == "jpg") {
     input = suppressWarnings(jpeg::readJPEG(input))
@@ -68,25 +69,19 @@ plot_image = function(input, rotate=0, keep_user_par = FALSE,
       input[input < 0] = 0
     }
     nr = convert_to_native_raster(input)
-    xlim = dim(input)[2]
-    ylim = dim(input)[1]
 
     if(new_page) {
       grid::grid.newpage()
     }
-    flip = FALSE
-    if(min(1,xlim/ylim)*asp > 1) {
-      flip = TRUE
-    }
-    if(flip) {
-      grid::grid.raster(nr, interpolate = FALSE,
-                        x=0.5, y=0.5,
-                        width=grid::unit(min(1,ylim/xlim), "snpc"),
-                        height=grid::unit(min(1,ylim/xlim)/asp, "snpc"))
+    if(!return_grob) {
+      grid::pushViewport(
+        grid::viewport(layout = grid::grid.layout(1,1,
+                                                  widths=grid::unit(1,"null"),
+                                                  height=grid::unit(1/asp,"null"), respect = TRUE))
+      )
+      grid::grid.raster(nr, interpolate = FALSE)
     } else {
-      grid::grid.raster(nr, interpolate = FALSE,
-                        width=grid::unit(min(1,xlim/ylim)*asp, "snpc"),
-                        height=grid::unit(min(1,ylim/xlim), "snpc"))
+      grid::rasterGrob(nr, interpolate = FALSE)
     }
   } else if(length(dim(input)) == 2) {
     if(number_of_rots != 0) {
@@ -98,26 +93,21 @@ plot_image = function(input, rotate=0, keep_user_par = FALSE,
       input[input > 1] = 1
       input[input < 0] = 0
     }
-    xlim = dim(input)[2]
-    ylim = dim(input)[1]
     array_from_mat = array(input,dim=c(nrow(input),ncol(input),3))
     nr = convert_to_native_raster(array_from_mat)
+
     if(new_page) {
       grid::grid.newpage()
     }
-    flip = FALSE
-    if(min(1,xlim/ylim)*asp > 1) {
-      flip = TRUE
-    }
-    if(flip) {
-      grid::grid.raster(nr, interpolate = FALSE,
-                        x=0.5, y=0.5,
-                        width=grid::unit(min(1,ylim/xlim), "snpc"),
-                        height=grid::unit(min(1,ylim/xlim)/asp, "snpc"))
+    if(!return_grob) {
+      grid::pushViewport(
+        grid::viewport(layout = grid::grid.layout(1,1,
+                                                  widths=grid::unit(1,"null"),
+                                                  height=grid::unit(1/asp,"null"), respect = TRUE))
+      )
+      grid::grid.raster(nr, interpolate = FALSE)
     } else {
-      grid::grid.raster(nr, interpolate = FALSE,
-                        width=grid::unit(min(1,xlim/ylim)*asp, "snpc"),
-                        height=grid::unit(min(1,ylim/xlim), "snpc"))
+      grid::rasterGrob(nr, interpolate = FALSE)
     }
   } else {
     stop("`input` is neither array nor matrix--convert to either to plot.")
